@@ -8,7 +8,7 @@ from fastapi.logger import logger
 from fastapi.security import HTTPAuthorizationCredentials, HTTPBearer
 from pydantic import BaseModel
 
-from awesome_sso.exceptions import BadRequest, NotFound, Unauthorized
+from awesome_exception.exceptions import BadRequest, NotFound, Unauthorized
 from awesome_sso.service.settings import Settings
 from awesome_sso.service.user.schema import AwesomeUserType, RegisterModel
 from awesome_sso.util.constant import MOCK_USER_ID
